==> guikachu-0.1.tar.gz: guikachu-0.1/src/string-win.h <==
//$Id: string-win.h,v 1.1 2001/02/22 21:56:04 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKATCHU_STRING_WIN_H
#define GUIKATCHU_STRING_WIN_H

namespace Guikachu
{
    namespace GUI
    {
	class StringWindow;
    }
}

#include "config.h"

#include "string-res.h"

#include <gtk--/window.h>
#include <gtk--/entry.h>
#include <gtk--/text.h>

#include <glade/glade-xml.h>

namespace Guikachu
{
    namespace GUI
    {
	class StringWindow: public SigC::Object
	{
	    Resources::String *res;

	    GladeXML    *gui;
	    Gtk::Window *window;
	    
	    Gtk::Entry  *id_entry;
	    Gtk::Text   *text_entry;

	public:
	    StringWindow (Guikachu::Resources::String *res_);
	    ~StringWindow ();

	    void show ();
	private:
	    int delete_event_impl (GdkEventAny *e);
	    void update ();
	    void id_entry_cb (GdkEventFocus *e);

	    void text_entry_cb ();
	    bool block_text_entry_cb;
	};
    };
};

#endif /* !GUIKATCHU_STRING_WIN_H */

==> guikachu-0.3.tar.gz: guikachu-0.3/src/string-win.h <==
//$Id: string-win.h,v 1.3 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKATCHU_STRING_WIN_H
#define GUIKATCHU_STRING_WIN_H

namespace Guikachu
{
    namespace GUI
    {
	class StringWindow;
    }
}

#include "string-res.h"

#include <gtk--/window.h>
#include <gtk--/entry.h>
#include <gtk--/text.h>

#include <glade/glade-xml.h>

namespace Guikachu
{
    namespace GUI
    {
	class StringWindow: public SigC::Object
	{
	    Resources::String *res;

	    GladeXML    *gui;
	    Gtk::Window *window;
	    
	    Gtk::Entry  *id_entry;
	    Gtk::Text   *text_entry;

	public:
	    StringWindow (Guikachu::Resources::String *res);
	    ~StringWindow ();

	    void show ();
	private:
	    int delete_event_impl (GdkEventAny *e);
	    void update ();
	    void id_entry_cb (GdkEventFocus *e);

	    void text_entry_cb ();
	    bool block_text_entry_cb;
	};
    };
};

#endif /* !GUIKATCHU_STRING_WIN_H */
